==> jc-1.4.0.tar.gz: gnu/xml/util/XCat__24DoneDelegation.h <==
// class gnu.xml.util.XCat$DoneDelegation

// class file dependencies
// @dep_class c3ea487f21578016 gnu_xml_util_XCat__24DoneDelegation
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_gnu_xml_util_XCat__24DoneDelegation_H_
#define _JC_gnu_xml_util_XCat__24DoneDelegation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs	_jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs	_jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$refs	_jc_gnu_xml_util_XCat__24DoneDelegation$refs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs	_jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$object	_jc_gnu_xml_util_XCat__24DoneDelegation$object;

typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vmethods	_jc_gnu_xml_util_XCat__24DoneDelegation$vmethods;
typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtable	_jc_gnu_xml_util_XCat__24DoneDelegation$vtable;
typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtype	_jc_gnu_xml_util_XCat__24DoneDelegation$vtype;

// Constructors
extern void _jc_gnu_xml_util_XCat__24DoneDelegation$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_XCat__24DoneDelegation$object *);

// Virtual methods structure
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vmethods	gnu_xml_util_XCat__24DoneDelegation;
};

// Vtype
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$refs {
    _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs	gnu_xml_util_XCat__24DoneDelegation;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs	gnu_xml_util_XCat__24DoneDelegation;
};

// Object instance structure
struct _jc_gnu_xml_util_XCat__24DoneDelegation$object {
	_jc_gnu_xml_util_XCat__24DoneDelegation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vtype	*vtype;
	_jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_XCat__24DoneDelegation$vtype _jc_gnu_xml_util_XCat__24DoneDelegation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_XCat__24DoneDelegation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_XCat__24DoneDelegation$class_object;

#endif	/* _JC_gnu_xml_util_XCat__24DoneDelegation_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/XCat__24DoneDelegation.h <==
// class gnu.xml.util.XCat$DoneDelegation

// class file dependencies
// @dep_class c3ea487f21578016 gnu_xml_util_XCat__24DoneDelegation
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_gnu_xml_util_XCat__24DoneDelegation_H_
#define _JC_gnu_xml_util_XCat__24DoneDelegation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs	_jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs	_jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$refs	_jc_gnu_xml_util_XCat__24DoneDelegation$refs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs	_jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs;
typedef struct _jc_gnu_xml_util_XCat__24DoneDelegation$object	_jc_gnu_xml_util_XCat__24DoneDelegation$object;

typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vmethods	_jc_gnu_xml_util_XCat__24DoneDelegation$vmethods;
typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtable	_jc_gnu_xml_util_XCat__24DoneDelegation$vtable;
typedef const struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtype	_jc_gnu_xml_util_XCat__24DoneDelegation$vtype;

// Constructors
extern void _jc_gnu_xml_util_XCat__24DoneDelegation$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_XCat__24DoneDelegation$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vmethods	gnu_xml_util_XCat__24DoneDelegation;
};

// Vtype
struct _jc_gnu_xml_util_XCat__24DoneDelegation$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$refs {
    _jc_gnu_xml_util_XCat__24DoneDelegation$sub_refs	gnu_xml_util_XCat__24DoneDelegation;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_gnu_xml_util_XCat__24DoneDelegation$sub_nonrefs	gnu_xml_util_XCat__24DoneDelegation;
};

// Object instance structure
struct _jc_gnu_xml_util_XCat__24DoneDelegation$object {
	_jc_gnu_xml_util_XCat__24DoneDelegation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_XCat__24DoneDelegation$vtype	*vtype;
	_jc_gnu_xml_util_XCat__24DoneDelegation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_XCat__24DoneDelegation$vtype _jc_gnu_xml_util_XCat__24DoneDelegation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_XCat__24DoneDelegation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_XCat__24DoneDelegation$class_object;

#endif	/* _JC_gnu_xml_util_XCat__24DoneDelegation_H_ */
